@@ -15,7 +15,7 @@ class ChatMemberUpdated(base.TelegramObject):
     https://core.telegram.org/bots/api#chatmemberupdated
     """
     chat: Chat = fields.Field(base=Chat)
-    from_user: User = fields.Field(base=User)
+    from_user: User = fields.Field(alias="from", base=User)
     date: datetime.datetime = fields.DateTimeField()
     old_chat_member: ChatMember = fields.Field(base=ChatMember)
     new_chat_member: ChatMember = fields.Field(base=ChatMember)
